@@ -19,15 +19,18 @@ package org.eclipse.aether.connector.basic;
  * under the License.
  */
 
+import static java.util.Objects.requireNonNull;
+
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.URI;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import static java.util.Objects.requireNonNull;
 import java.util.Set;
 import java.util.concurrent.Executor;
 import java.util.concurrent.ExecutorService;
@@ -54,17 +57,19 @@ import org.eclipse.aether.spi.connector.transport.PutTask;
 import org.eclipse.aether.spi.connector.transport.Transporter;
 import org.eclipse.aether.spi.connector.transport.TransporterProvider;
 import org.eclipse.aether.spi.io.FileProcessor;
-import org.eclipse.aether.spi.log.Logger;
 import org.eclipse.aether.transfer.ChecksumFailureException;
 import org.eclipse.aether.transfer.NoRepositoryConnectorException;
 import org.eclipse.aether.transfer.NoRepositoryLayoutException;
 import org.eclipse.aether.transfer.NoTransporterException;
 import org.eclipse.aether.transfer.TransferEvent;
 import org.eclipse.aether.transfer.TransferResource;
+import org.eclipse.aether.transform.FileTransformer;
 import org.eclipse.aether.util.ChecksumUtils;
 import org.eclipse.aether.util.ConfigUtils;
 import org.eclipse.aether.util.concurrency.RunnableErrorForwarder;
 import org.eclipse.aether.util.concurrency.WorkerThreadFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  */
@@ -80,7 +85,7 @@ final class BasicRepositoryConnector
 
     private static final String CONFIG_PROP_SMART_CHECKSUMS = "aether.connector.smartChecksums";
 
-    private final Logger logger;
+    private static final Logger LOGGER = LoggerFactory.getLogger( BasicRepositoryConnector.class );
 
     private final FileProcessor fileProcessor;
 
@@ -106,10 +111,9 @@ final class BasicRepositoryConnector
 
     private boolean closed;
 
-    public BasicRepositoryConnector( RepositorySystemSession session, RemoteRepository repository,
+    BasicRepositoryConnector( RepositorySystemSession session, RemoteRepository repository,
                                      TransporterProvider transporterProvider, RepositoryLayoutProvider layoutProvider,
-                                     ChecksumPolicyProvider checksumPolicyProvider, FileProcessor fileProcessor,
-                                     Logger logger )
+                                     ChecksumPolicyProvider checksumPolicyProvider, FileProcessor fileProcessor )
         throws NoRepositoryConnectorException
     {
         try
@@ -133,7 +137,6 @@ final class BasicRepositoryConnector
         this.session = session;
         this.repository = repository;
         this.fileProcessor = fileProcessor;
-        this.logger = logger;
 
         maxThreads = ConfigUtils.getInteger( session, 5, CONFIG_PROP_THREADS, "maven.artifact.threads" );
         smartChecksums = ConfigUtils.getBoolean( session, true, CONFIG_PROP_SMART_CHECKSUMS );
@@ -150,7 +153,7 @@ final class BasicRepositoryConnector
             ConfigUtils.getInteger( session, ConfigurationProperties.DEFAULT_REQUEST_TIMEOUT,
                                     ConfigurationProperties.REQUEST_TIMEOUT + '.' + repository.getId(),
                                     ConfigurationProperties.REQUEST_TIMEOUT );
-        partialFileFactory = new PartialFile.Factory( resumeDownloads, resumeThreshold, requestTimeout, logger );
+        partialFileFactory = new PartialFile.Factory( resumeDownloads, resumeThreshold, requestTimeout );
     }
 
     private Executor getExecutor( Collection<?> artifacts, Collection<?> metadatas )
@@ -280,7 +283,7 @@ final class BasicRepositoryConnector
 
             List<RepositoryLayout.Checksum> checksums = layout.getChecksums( transfer.getArtifact(), true, location );
 
-            Runnable task = new PutTaskRunner( location, transfer.getFile(), checksums, listener );
+            Runnable task = new PutTaskRunner( location, transfer.getFile(), transfer.getFileTransformer(), checksums, listener );
             task.run();
         }
 
@@ -346,7 +349,7 @@ final class BasicRepositoryConnector
 
         protected final TransferTransportListener<?> listener;
 
-        public TaskRunner( URI path, TransferTransportListener<?> listener )
+        TaskRunner( URI path, TransferTransportListener<?> listener )
         {
             this.path = path;
             this.listener = listener;
@@ -375,7 +378,7 @@ final class BasicRepositoryConnector
         extends TaskRunner
     {
 
-        public PeekTaskRunner( URI path, TransferTransportListener<?> listener )
+        PeekTaskRunner( URI path, TransferTransportListener<?> listener )
         {
             super( path, listener );
         }
@@ -397,13 +400,13 @@ final class BasicRepositoryConnector
 
         private final ChecksumValidator checksumValidator;
 
-        public GetTaskRunner( URI path, File file, ChecksumPolicy checksumPolicy,
+        GetTaskRunner( URI path, File file, ChecksumPolicy checksumPolicy,
                               List<RepositoryLayout.Checksum> checksums, TransferTransportListener<?> listener )
         {
             super( path, listener );
             this.file = requireNonNull( file, "destination file cannot be null" );
             checksumValidator =
-                new ChecksumValidator( logger, file, fileProcessor, this, checksumPolicy, safe( checksums ) );
+                new ChecksumValidator( file, fileProcessor, this, checksumPolicy, safe( checksums ) );
         }
 
         public void checkRemoteAccess()
@@ -438,7 +441,7 @@ final class BasicRepositoryConnector
             PartialFile partFile = partialFileFactory.newInstance( file, this );
             if ( partFile == null )
             {
-                logger.debug( "Concurrent download of " + file + " just finished, skipping download" );
+                LOGGER.debug( "Concurrent download of {} just finished, skipping download", file );
                 return;
             }
 
@@ -496,24 +499,70 @@ final class BasicRepositoryConnector
 
         private final File file;
 
+        private final FileTransformer fileTransformer; 
+
         private final Collection<RepositoryLayout.Checksum> checksums;
 
-        public PutTaskRunner( URI path, File file, List<RepositoryLayout.Checksum> checksums,
+        PutTaskRunner( URI path, File file, List<RepositoryLayout.Checksum> checksums,
+                       TransferTransportListener<?> listener )
+        {
+            this( path, file, null, checksums, listener );
+        }
+
+        /**
+         * <strong>IMPORTANT</strong> When using a fileTransformer, the content of the file is stored in memory to 
+         * ensure that file content and checksums stay in sync!
+         * 
+         * @param path
+         * @param file
+         * @param fileTransformer
+         * @param checksums
+         * @param listener
+         */
+        PutTaskRunner( URI path, File file, FileTransformer fileTransformer, List<RepositoryLayout.Checksum> checksums,
                               TransferTransportListener<?> listener )
         {
             super( path, listener );
             this.file = requireNonNull( file, "source file cannot be null" );
+            this.fileTransformer = fileTransformer;
             this.checksums = safe( checksums );
         }
 
         protected void runTask()
             throws Exception
         {
-            transporter.put( new PutTask( path ).setDataFile( file ).setListener( listener ) );
-            uploadChecksums( file, path );
+            if ( fileTransformer != null )
+            {
+                // transform data once to byte array, ensure constant data for checksum
+                ByteArrayOutputStream baos = new ByteArrayOutputStream();
+                byte[] buffer = new byte[1024];
+                
+                try ( InputStream transformData = fileTransformer.transformData( file ) )
+                {
+                    for ( int read; ( read = transformData.read( buffer, 0, buffer.length ) ) != -1; )
+                    {
+                        baos.write( buffer, 0, read );
+                    }
+                }
+
+                byte[] bytes = baos.toByteArray();
+                transporter.put( new PutTask( path ).setDataBytes( bytes ).setListener( listener ) );
+                uploadChecksums( file, bytes, path );
+            }
+            else
+            {
+                transporter.put( new PutTask( path ).setDataFile( file ).setListener( listener ) );
+                uploadChecksums( file, null , path );
+            }
         }
 
-        private void uploadChecksums( File file, URI location )
+        /**
+         * 
+         * @param file source
+         * @param bytes transformed data from file or {@code null}
+         * @param location target
+         */
+        private void uploadChecksums( File file, byte[] bytes, URI location )
         {
             if ( checksums.isEmpty() )
             {
@@ -521,12 +570,22 @@ final class BasicRepositoryConnector
             }
             try
             {
-                Set<String> algos = new HashSet<String>();
+                Set<String> algos = new HashSet<>();
                 for ( RepositoryLayout.Checksum checksum : checksums )
                 {
                     algos.add( checksum.getAlgorithm() );
                 }
-                Map<String, Object> sumsByAlgo = ChecksumUtils.calc( file, algos );
+                
+                Map<String, Object> sumsByAlgo;
+                if ( bytes != null )
+                {
+                    sumsByAlgo = ChecksumUtils.calc( bytes, algos );
+                }
+                else
+                {
+                    sumsByAlgo = ChecksumUtils.calc( file, algos );
+                }
+
                 for ( RepositoryLayout.Checksum checksum : checksums )
                 {
                     uploadChecksum( checksum.getLocation(), sumsByAlgo.get( checksum.getAlgorithm() ) );
@@ -535,13 +594,13 @@ final class BasicRepositoryConnector
             catch ( IOException e )
             {
                 String msg = "Failed to upload checksums for " + file + ": " + e.getMessage();
-                if ( logger.isDebugEnabled() )
+                if ( LOGGER.isDebugEnabled() )
                 {
-                    logger.warn( msg, e );
+                    LOGGER.warn( msg, e );
                 }
                 else
                 {
-                    logger.warn( msg );
+                    LOGGER.warn( msg );
                 }
             }
         }
@@ -559,13 +618,13 @@ final class BasicRepositoryConnector
             catch ( Exception e )
             {
                 String msg = "Failed to upload checksum " + location + ": " + e.getMessage();
-                if ( logger.isDebugEnabled() )
+                if ( LOGGER.isDebugEnabled() )
                 {
-                    logger.warn( msg, e );
+                    LOGGER.warn( msg, e );
                 }
                 else
                 {
-                    logger.warn( msg );
+                    LOGGER.warn( msg );
                 }
             }
         }
