@@ -37,30 +37,32 @@ import org.junit.Test;
 
 public class ChecksumUtilTest
 {
-    private File emptyFile;
+    private static final String EMPTY = "EMPTY";
+    private static final String PATTERN = "PATTERN";
+    private static final String TEXT = "TEXT";
+    
+    private Map<String, File> files = new HashMap<>(3);
+    
+    private Map<String, byte[]> bytes = new HashMap<>(3);
+    
+    private static Map<String, String> emptyChecksums = new HashMap<>();
 
-    private File patternFile;
+    private static Map<String, String> patternChecksums = new HashMap<>();
 
-    private File textFile;
+    private static Map<String, String> textChecksums = new HashMap<>();
 
-    private static Map<String, String> emptyFileChecksums = new HashMap<String, String>();
-
-    private static Map<String, String> patternFileChecksums = new HashMap<String, String>();
-
-    private static Map<String, String> textFileChecksums = new HashMap<String, String>();
-
-    private Map<File, Map<String, String>> sums = new HashMap<File, Map<String, String>>();
+    private Map<String, Map<String, String>> sums = new HashMap<>();
 
     @BeforeClass
     public static void beforeClass()
         throws IOException
     {
-        emptyFileChecksums.put( "MD5", "d41d8cd98f00b204e9800998ecf8427e" );
-        emptyFileChecksums.put( "SHA-1", "da39a3ee5e6b4b0d3255bfef95601890afd80709" );
-        patternFileChecksums.put( "MD5", "14f01d6c7de7d4cf0a4887baa3528b5a" );
-        patternFileChecksums.put( "SHA-1", "feeeda19f626f9b0ef6cbf5948c1ec9531694295" );
-        textFileChecksums.put( "MD5", "12582d1a662cefe3385f2113998e43ed" );
-        textFileChecksums.put( "SHA-1", "a8ae272db549850eef2ff54376f8cac2770745ee" );
+        emptyChecksums.put( "MD5", "d41d8cd98f00b204e9800998ecf8427e" );
+        emptyChecksums.put( "SHA-1", "da39a3ee5e6b4b0d3255bfef95601890afd80709" );
+        patternChecksums.put( "MD5", "14f01d6c7de7d4cf0a4887baa3528b5a" );
+        patternChecksums.put( "SHA-1", "feeeda19f626f9b0ef6cbf5948c1ec9531694295" );
+        textChecksums.put( "MD5", "12582d1a662cefe3385f2113998e43ed" );
+        textChecksums.put( "SHA-1", "a8ae272db549850eef2ff54376f8cac2770745ee" );
     }
 
     @Before
@@ -69,15 +71,20 @@ public class ChecksumUtilTest
     {
         sums.clear();
 
-        emptyFile = createTempFile( new byte[] {}, 0 );
-        sums.put( emptyFile, emptyFileChecksums );
+        byte[] emptyBytes = new byte[0];
+        bytes.put( EMPTY, emptyBytes );
+        files.put( EMPTY, createTempFile( emptyBytes, 0 ) );
+        sums.put( EMPTY, emptyChecksums );
 
-        patternFile =
-            createTempFile( new byte[] { 0, 1, 2, 4, 8, 16, 32, 64, 127, -1, -2, -4, -8, -16, -32, -64, -127 }, 1000 );
-        sums.put( patternFile, patternFileChecksums );
+        byte[] patternBytes = writeBytes( new byte[] { 0, 1, 2, 4, 8, 16, 32, 64, 127, -1, -2, -4, -8, -16, -32, -64, -127 }, 1000 );
+        bytes.put( PATTERN, patternBytes );
+        files.put( PATTERN, createTempFile( patternBytes, 1 ) );
+        sums.put( PATTERN, patternChecksums );
 
-        textFile = createTempFile( "the quick brown fox jumps over the lazy dog\n".getBytes( StandardCharsets.UTF_8 ), 500 );
-        sums.put( textFile, textFileChecksums );
+        byte[] textBytes = writeBytes( "the quick brown fox jumps over the lazy dog\n".getBytes( StandardCharsets.UTF_8 ), 500 );
+        bytes.put( TEXT, textBytes );
+        files.put( TEXT, createTempFile( textBytes, 1 ) );
+        sums.put( TEXT, textChecksums );
 
     }
 
@@ -87,10 +94,10 @@ public class ChecksumUtilTest
     {
         Map<String, Object> checksums = null;
 
-        for ( File file : new File[] { emptyFile, patternFile, textFile } )
+        for ( Map.Entry<String,File> fileEntry : files.entrySet() )
         {
 
-            checksums = ChecksumUtils.calc( file, Arrays.asList( "SHA-1", "MD5" ) );
+            checksums = ChecksumUtils.calc( fileEntry.getValue(), Arrays.asList( "SHA-1", "MD5" ) );
 
             for ( Entry<String, Object> entry : checksums.entrySet() )
             {
@@ -99,11 +106,11 @@ public class ChecksumUtilTest
                     throw (Throwable) entry.getValue();
                 }
                 String actual = entry.getValue().toString();
-                String expected = sums.get( file ).get( entry.getKey() );
-                assertEquals( String.format( "checksums do not match for '%s', algorithm '%s'", file.getName(),
+                String expected = sums.get( fileEntry.getKey() ).get( entry.getKey() );
+                assertEquals( String.format( "checksums do not match for '%s', algorithm '%s'", fileEntry.getValue().getName(),
                                              entry.getKey() ), expected, actual );
             }
-            assertTrue( "Could not delete file", file.delete() );
+            assertTrue( "Could not delete file", fileEntry.getValue().delete() );
         }
     }
 
@@ -111,7 +118,7 @@ public class ChecksumUtilTest
     public void testFileHandleLeakage()
         throws IOException
     {
-        for ( File file : new File[] { emptyFile, patternFile, textFile } )
+        for ( File file : files.values() )
         {
             for ( int i = 0; i < 150; i++ )
             {
@@ -182,5 +189,38 @@ public class ChecksumUtilTest
         assertEquals( "ff", ChecksumUtils.toHexString( new byte[] { -1 } ) );
         assertEquals( "00017f", ChecksumUtils.toHexString( new byte[] { 0, 1, 127 } ) );
     }
+    
+    @Test
+    public void testCalcWithByteArray() throws Throwable
+    {
+        Map<String, Object> checksums = null;
 
+        for ( Map.Entry<String, byte[]> bytesEntry : bytes.entrySet() )
+        {
+            checksums = ChecksumUtils.calc( bytesEntry.getValue(), Arrays.asList( "SHA-1", "MD5" ) );
+
+            for ( Entry<String, Object> entry : checksums.entrySet() )
+            {
+                if ( entry.getValue() instanceof Throwable )
+                {
+                    throw (Throwable) entry.getValue();
+                }
+                String actual = entry.getValue().toString();
+                String expected = sums.get( bytesEntry.getKey() ).get( entry.getKey() );
+                assertEquals( String.format( "checksums do not match for '%s', algorithm '%s'", bytesEntry.getKey(),
+                                             entry.getKey() ), expected, actual );
+            }
+        }
+    }
+
+    private byte[] writeBytes( byte[] pattern, int repeat )
+    {
+        byte[] result = new byte[pattern.length * repeat];
+        for ( int i = 0; i < repeat; i++ )
+        {
+            System.arraycopy( pattern, 0, result, i * pattern.length, pattern.length );
+        }
+        return result;
+    }
 }
+
